searchData={"items":[{"type":"module","title":"Supabase.PostgREST","doc":"Provides a suite of functions to interact with a Supabase PostgREST API, allowing\nfor construction and execution of queries using a fluent interface. This module is designed\nto facilitate the building of complex queries and their execution in the context of a Supabase\ndatabase application.\n\nFor detailed usage examples and more information, refer to the official Supabase documentation:\nhttps://supabase.com/docs","ref":"Supabase.PostgREST.html"},{"type":"function","title":"Supabase.PostgREST.and/3","doc":"Applies an \"AND\" condition to a query, allowing multiple conditions on different columns.\nThis can also be scoped to a foreign table if specified.","ref":"Supabase.PostgREST.html#and/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.and/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `columns`: A list of conditions that should all be met.\n- `opts`: Optional parameters, which can include specifying a foreign table.","ref":"Supabase.PostgREST.html#and/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.and/3","doc":"iex> PostgREST.and(filter_builder, [\"age > 18\", \"status = 'active'\"])","ref":"Supabase.PostgREST.html#and/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.and/3","doc":"- Supabase logical operations: https://supabase.com/docs/reference/javascript/using-filters#logical-operators","ref":"Supabase.PostgREST.html#and/3-see-also"},{"type":"function","title":"Supabase.PostgREST.contained_by/3","doc":"Adds a 'contained by' filter to the query, checking if the column's array or range is contained by the specified values.","ref":"Supabase.PostgREST.html#contained_by/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.contained_by/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `values`: The array of values that must contain the column's value.","ref":"Supabase.PostgREST.html#contained_by/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.contained_by/3","doc":"iex> PostgREST.contained_by(filter_builder, \"tags\", [\"urgent\", \"new\", \"old\"])","ref":"Supabase.PostgREST.html#contained_by/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.contained_by/3","doc":"- Supabase contained by filter: https://supabase.com/docs/reference/javascript/using-filters#contained-by","ref":"Supabase.PostgREST.html#contained_by/3-see-also"},{"type":"function","title":"Supabase.PostgREST.contained_by_object/3","doc":"Adds a 'contained by' filter for JSONB columns, checking if the column's JSONB value is contained by the specified JSON keys and values.","ref":"Supabase.PostgREST.html#contained_by_object/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.contained_by_object/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `data`: The JSON object that must contain the column's value.","ref":"Supabase.PostgREST.html#contained_by_object/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.contained_by_object/3","doc":"iex> PostgREST.contained_by_object(filter_builder, \"metadata\", %{type: \"info\"})","ref":"Supabase.PostgREST.html#contained_by_object/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.contained_by_object/3","doc":"- Supabase JSON contained by filter: https://supabase.com/docs/reference/javascript/using-filters#json-contained-by","ref":"Supabase.PostgREST.html#contained_by_object/3-see-also"},{"type":"function","title":"Supabase.PostgREST.contains/3","doc":"Adds a 'contains' filter to the query, checking if the column's array or range contains the specified values.","ref":"Supabase.PostgREST.html#contains/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.contains/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `values`: The array of values the column must contain.","ref":"Supabase.PostgREST.html#contains/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.contains/3","doc":"iex> PostgREST.contains(filter_builder, \"tags\", [\"urgent\", \"new\"])","ref":"Supabase.PostgREST.html#contains/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.contains/3","doc":"- Supabase contains filter: https://supabase.com/docs/reference/javascript/using-filters#contains","ref":"Supabase.PostgREST.html#contains/3-see-also"},{"type":"function","title":"Supabase.PostgREST.contains_object/3","doc":"Adds a 'contains' filter for JSONB columns, checking if the column's JSONB value contains the specified JSON keys and values.","ref":"Supabase.PostgREST.html#contains_object/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.contains_object/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `data`: The JSON object that must be contained within the column's value.","ref":"Supabase.PostgREST.html#contains_object/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.contains_object/3","doc":"iex> PostgREST.contains_object(filter_builder, \"metadata\", %{type: \"info\"})","ref":"Supabase.PostgREST.html#contains_object/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.contains_object/3","doc":"- Supabase JSON contains filter: https://supabase.com/docs/reference/javascript/using-filters#json-contains","ref":"Supabase.PostgREST.html#contains_object/3-see-also"},{"type":"function","title":"Supabase.PostgREST.delete/2","doc":"Deletes records from a table based on the conditions specified in the QueryBuilder.","ref":"Supabase.PostgREST.html#delete/2"},{"type":"function","title":"Parameters - Supabase.PostgREST.delete/2","doc":"- `query_builder`: The QueryBuilder to use.\n- `opts`: Options such as `:returning` and `:count`.","ref":"Supabase.PostgREST.html#delete/2-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.delete/2","doc":"iex> PostgREST.delete(query_builder, returning: :representation)","ref":"Supabase.PostgREST.html#delete/2-examples"},{"type":"function","title":"See also - Supabase.PostgREST.delete/2","doc":"- Supabase documentation on deletes: https://supabase.com/docs/reference/javascript/delete","ref":"Supabase.PostgREST.html#delete/2-see-also"},{"type":"function","title":"Supabase.PostgREST.eq/3","doc":"Adds an equality filter to the query, specifying that the column must equal a certain value.","ref":"Supabase.PostgREST.html#eq/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.eq/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The value the column must equal.","ref":"Supabase.PostgREST.html#eq/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.eq/3","doc":"iex> PostgREST.eq(filter_builder, \"id\", 123)","ref":"Supabase.PostgREST.html#eq/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.eq/3","doc":"- Supabase equality filters: https://supabase.com/docs/reference/javascript/using-filters#equality","ref":"Supabase.PostgREST.html#eq/3-see-also"},{"type":"function","title":"Supabase.PostgREST.execute/1","doc":"Executes the query built using the QueryBuilder or FilterBuilder instance and returns the raw result.","ref":"Supabase.PostgREST.html#execute/1"},{"type":"function","title":"Parameters - Supabase.PostgREST.execute/1","doc":"- `filter_builder`: The FilterBuilder or QueryBuilder instance to execute.","ref":"Supabase.PostgREST.html#execute/1-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.execute/1","doc":"iex> PostgREST.execute(filter_builder)","ref":"Supabase.PostgREST.html#execute/1-examples"},{"type":"function","title":"See also - Supabase.PostgREST.execute/1","doc":"- Supabase query execution: https://supabase.com/docs/reference/javascript/performing-queries","ref":"Supabase.PostgREST.html#execute/1-see-also"},{"type":"function","title":"Supabase.PostgREST.execute_string/1","doc":"Executes the query and returns the result as a JSON-encoded string.","ref":"Supabase.PostgREST.html#execute_string/1"},{"type":"function","title":"Parameters - Supabase.PostgREST.execute_string/1","doc":"- `filter_builder`: The FilterBuilder or QueryBuilder instance to execute.","ref":"Supabase.PostgREST.html#execute_string/1-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.execute_string/1","doc":"iex> PostgREST.execute_string(filter_builder)","ref":"Supabase.PostgREST.html#execute_string/1-examples"},{"type":"function","title":"See also - Supabase.PostgREST.execute_string/1","doc":"- Supabase query execution and response handling: https://supabase.com/docs/reference/javascript/performing-queries","ref":"Supabase.PostgREST.html#execute_string/1-see-also"},{"type":"function","title":"Supabase.PostgREST.execute_to/2","doc":"Executes the query and maps the resulting data to a specified schema struct, useful for casting the results to Elixir structs.","ref":"Supabase.PostgREST.html#execute_to/2"},{"type":"function","title":"Parameters - Supabase.PostgREST.execute_to/2","doc":"- `filter_builder`: The FilterBuilder or QueryBuilder instance to execute.\n- `schema`: The Elixir module representing the schema to which the results should be cast.","ref":"Supabase.PostgREST.html#execute_to/2-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.execute_to/2","doc":"iex> PostgREST.execute_to(filter_builder, User)","ref":"Supabase.PostgREST.html#execute_to/2-examples"},{"type":"function","title":"See also - Supabase.PostgREST.execute_to/2","doc":"- Supabase query execution and schema casting: https://supabase.com/docs/reference/javascript/performing-queries","ref":"Supabase.PostgREST.html#execute_to/2-see-also"},{"type":"function","title":"Supabase.PostgREST.execute_to_finch_request/1","doc":"Executes a query using the Finch HTTP client, formatting the request appropriately.","ref":"Supabase.PostgREST.html#execute_to_finch_request/1"},{"type":"function","title":"Parameters - Supabase.PostgREST.execute_to_finch_request/1","doc":"- `filter_builder`: The FilterBuilder or QueryBuilder instance to execute.\n- `schema`: Optional schema module to map the results.","ref":"Supabase.PostgREST.html#execute_to_finch_request/1-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.execute_to_finch_request/1","doc":"iex> PostgREST.execute_to_finch_request(filter_builder, User)","ref":"Supabase.PostgREST.html#execute_to_finch_request/1-examples"},{"type":"function","title":"See also - Supabase.PostgREST.execute_to_finch_request/1","doc":"- Supabase query execution: https://supabase.com/docs/reference/javascript/performing-queries","ref":"Supabase.PostgREST.html#execute_to_finch_request/1-see-also"},{"type":"function","title":"Supabase.PostgREST.from/2","doc":"Initializes a `QueryBuilder` for a specified table and client.","ref":"Supabase.PostgREST.html#from/2"},{"type":"function","title":"Parameters - Supabase.PostgREST.from/2","doc":"- `client`: The Supabase client used for authentication and configuration.\n- `table`: The database table name as a string.","ref":"Supabase.PostgREST.html#from/2-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.from/2","doc":"iex> PostgREST.from(client, \"users\")\n    %QueryBuilder{}","ref":"Supabase.PostgREST.html#from/2-examples"},{"type":"function","title":"See also - Supabase.PostgREST.from/2","doc":"- Supabase documentation on initializing queries: https://supabase.com/docs/reference/javascript/from","ref":"Supabase.PostgREST.html#from/2-see-also"},{"type":"function","title":"Supabase.PostgREST.gt/3","doc":"Adds a 'greater than' filter to the query, specifying that the column's value must be greater than the specified value.","ref":"Supabase.PostgREST.html#gt/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.gt/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The value that the column must be greater than.","ref":"Supabase.PostgREST.html#gt/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.gt/3","doc":"iex> PostgREST.gt(filter_builder, \"age\", 21)","ref":"Supabase.PostgREST.html#gt/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.gt/3","doc":"- Supabase greater than filter: https://supabase.com/docs/reference/javascript/using-filters#greater-than","ref":"Supabase.PostgREST.html#gt/3-see-also"},{"type":"function","title":"Supabase.PostgREST.gte/3","doc":"Adds a 'greater than or equal to' filter to the query, specifying that the column's value must be greater than or equal to the specified value.","ref":"Supabase.PostgREST.html#gte/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.gte/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The value that the column must be greater than or equal to.","ref":"Supabase.PostgREST.html#gte/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.gte/3","doc":"iex> PostgREST.gte(filter_builder, \"age\", 21)","ref":"Supabase.PostgREST.html#gte/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.gte/3","doc":"- Supabase greater than or equal filter: https://supabase.com/docs/reference/javascript/using-filters#greater-than-or-equal","ref":"Supabase.PostgREST.html#gte/3-see-also"},{"type":"function","title":"Supabase.PostgREST.ilike/3","doc":"Adds an 'ilike' filter to the query, allowing for case-insensitive pattern matching (SQL ILIKE).","ref":"Supabase.PostgREST.html#ilike/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.ilike/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The pattern to match against the column's value, ignoring case.","ref":"Supabase.PostgREST.html#ilike/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.ilike/3","doc":"iex> PostgREST.ilike(filter_builder, \"name\", \"%john%\")","ref":"Supabase.PostgREST.html#ilike/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.ilike/3","doc":"- Supabase ilike filter: https://supabase.com/docs/reference/javascript/using-filters#ilike","ref":"Supabase.PostgREST.html#ilike/3-see-also"},{"type":"function","title":"Supabase.PostgREST.in/3","doc":"Filters the query by checking if the column's value is within an array of specified values.","ref":"Supabase.PostgREST.html#in/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.in/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to filter.\n- `values`: A list of acceptable values for the column.","ref":"Supabase.PostgREST.html#in/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.in/3","doc":"iex> PostgREST.in(filter_builder, \"status\", [\"active\", \"pending\", \"closed\"])","ref":"Supabase.PostgREST.html#in/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.in/3","doc":"- Supabase \"IN\" filters: https://supabase.com/docs/reference/javascript/using-filters#in","ref":"Supabase.PostgREST.html#in/3-see-also"},{"type":"function","title":"Supabase.PostgREST.insert/3","doc":"Inserts new records into the database. Supports conflict resolution and specifying how the\nresult should be returned.","ref":"Supabase.PostgREST.html#insert/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.insert/3","doc":"- `query_builder`: The QueryBuilder to use.\n- `data`: The data to be inserted, typically a map or a list of maps.\n- `opts`: Options like `:on_conflict`, `:returning`, and `:count`.","ref":"Supabase.PostgREST.html#insert/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.insert/3","doc":"iex> PostgREST.insert(query_builder, %{name: \"John\"}, on_conflict: \"name\", returning: :minimal)","ref":"Supabase.PostgREST.html#insert/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.insert/3","doc":"- Supabase documentation on inserts: https://supabase.com/docs/reference/javascript/insert","ref":"Supabase.PostgREST.html#insert/3-see-also"},{"type":"function","title":"Supabase.PostgREST.is/3","doc":"Adds an 'is' filter to the query, specifically for checking against `null` or boolean values.","ref":"Supabase.PostgREST.html#is/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.is/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The value to check the column against (typically null or a boolean).","ref":"Supabase.PostgREST.html#is/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.is/3","doc":"iex> PostgREST.is(filter_builder, \"name\", nil)","ref":"Supabase.PostgREST.html#is/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.is/3","doc":"- Supabase is filter: https://supabase.com/docs/reference/javascript/using-filters#is","ref":"Supabase.PostgREST.html#is/3-see-also"},{"type":"function","title":"Supabase.PostgREST.like/3","doc":"Adds a 'like' filter to the query, allowing for simple pattern matching (SQL LIKE).","ref":"Supabase.PostgREST.html#like/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.like/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The pattern to match against the column's value.","ref":"Supabase.PostgREST.html#like/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.like/3","doc":"iex> PostgREST.like(filter_builder, \"name\", \"%John%\")","ref":"Supabase.PostgREST.html#like/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.like/3","doc":"- Supabase like filter: https://supabase.com/docs/reference/javascript/using-filters#like","ref":"Supabase.PostgREST.html#like/3-see-also"},{"type":"function","title":"Supabase.PostgREST.limit/3","doc":"Limits the number of results returned by the query, optionally scoping this limit to a specific foreign table.","ref":"Supabase.PostgREST.html#limit/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.limit/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `count`: The maximum number of results to return.\n- `opts`: Optional parameters, which may include a foreign table.","ref":"Supabase.PostgREST.html#limit/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.limit/3","doc":"iex> PostgREST.limit(filter_builder, 10)","ref":"Supabase.PostgREST.html#limit/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.limit/3","doc":"- Supabase query limits: https://supabase.com/docs/reference/javascript/using-filters#limit","ref":"Supabase.PostgREST.html#limit/3-see-also"},{"type":"function","title":"Supabase.PostgREST.lt/3","doc":"Adds a 'less than' filter to the query, specifying that the column's value must be less than the specified value.","ref":"Supabase.PostgREST.html#lt/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.lt/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The value that the column must be less than.","ref":"Supabase.PostgREST.html#lt/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.lt/3","doc":"iex> PostgREST.lt(filter_builder, \"age\", 65)","ref":"Supabase.PostgREST.html#lt/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.lt/3","doc":"- Supabase less than filter: https://supabase.com/docs/reference/javascript/using-filters#less-than","ref":"Supabase.PostgREST.html#lt/3-see-also"},{"type":"function","title":"Supabase.PostgREST.lte/3","doc":"Adds a 'less than or equal to' filter to the query, specifying that the column's value must be less than or equal to the specified value.","ref":"Supabase.PostgREST.html#lte/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.lte/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The value that the column must be less than or equal to.","ref":"Supabase.PostgREST.html#lte/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.lte/3","doc":"iex> PostgREST.lte(filter_builder, \"age\", 65)","ref":"Supabase.PostgREST.html#lte/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.lte/3","doc":"- Supabase less than or equal filter: https://supabase.com/docs/reference/javascript/using-filters#less-than-or-equal","ref":"Supabase.PostgREST.html#lte/3-see-also"},{"type":"function","title":"Supabase.PostgREST.match/2","doc":"Orders the results of the query by a specified column. You can specify ascending or descending order,\nand handle nulls first or last.","ref":"Supabase.PostgREST.html#match/2"},{"type":"function","title":"Parameters - Supabase.PostgREST.match/2","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column by which to order the results.\n- `opts`: Options such as direction (`:asc` or `:desc`) and null handling (`:null_first` or `:null_last`).","ref":"Supabase.PostgREST.html#match/2-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.match/2","doc":"iex> PostgREST.order(filter_builder, \"created_at\", asc: true, null_first: false)","ref":"Supabase.PostgREST.html#match/2-examples"},{"type":"function","title":"See also - Supabase.PostgREST.match/2","doc":"- Supabase ordering results: https://supabase.com/docs/reference/javascript/using-filters#order","ref":"Supabase.PostgREST.html#match/2-see-also"},{"type":"function","title":"Supabase.PostgREST.neq/3","doc":"Adds a 'not equal' filter to the query, specifying that the column's value must not equal the specified value.","ref":"Supabase.PostgREST.html#neq/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.neq/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The value that the column must not equal.","ref":"Supabase.PostgREST.html#neq/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.neq/3","doc":"iex> PostgREST.neq(filter_builder, \"status\", \"inactive\")","ref":"Supabase.PostgREST.html#neq/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.neq/3","doc":"- Supabase not equal filter: https://supabase.com/docs/reference/javascript/using-filters#not-equal","ref":"Supabase.PostgREST.html#neq/3-see-also"},{"type":"function","title":"Supabase.PostgREST.not/4","doc":"Applies a \"NOT\" condition to the query, negating a specified condition.","ref":"Supabase.PostgREST.html#not/4"},{"type":"function","title":"Parameters - Supabase.PostgREST.not/4","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the negation.\n- `op`: The operator used in the condition (e.g., \"eq\", \"gt\").\n- `value`: The value to compare against.","ref":"Supabase.PostgREST.html#not/4-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.not/4","doc":"iex> PostgREST.not(filter_builder, \"status\", \"eq\", \"active\")","ref":"Supabase.PostgREST.html#not/4-examples"},{"type":"function","title":"See also - Supabase.PostgREST.not/4","doc":"- Supabase negation filters: https://supabase.com/docs/reference/javascript/using-filters#negation","ref":"Supabase.PostgREST.html#not/4-see-also"},{"type":"function","title":"Supabase.PostgREST.or/3","doc":"Applies an \"OR\" condition to a query, combining multiple conditions on different columns\nwhere at least one condition must be met. This can also be scoped to a foreign table.","ref":"Supabase.PostgREST.html#or/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.or/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `columns`: A list of conditions where at least one should be met.\n- `opts`: Optional parameters, which can include specifying a foreign table.","ref":"Supabase.PostgREST.html#or/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.or/3","doc":"iex> PostgREST.or(filter_builder, [\"age < 18\", \"status = 'inactive'\"])","ref":"Supabase.PostgREST.html#or/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.or/3","doc":"- Further details on logical operations in Supabase: https://supabase.com/docs/reference/javascript/using-filters#logical-operators","ref":"Supabase.PostgREST.html#or/3-see-also"},{"type":"function","title":"Supabase.PostgREST.order/3","doc":"Orders the results of the query by a specified column. You can specify ascending or descending order,\nand handle nulls first or last.","ref":"Supabase.PostgREST.html#order/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.order/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column by which to order the results.\n- `opts`: Options such as direction (`:asc` or `:desc`) and null handling (`:null_first` or `:null_last`).","ref":"Supabase.PostgREST.html#order/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.order/3","doc":"iex> PostgREST.order(filter_builder, \"created_at\", asc: true, null_first: false)","ref":"Supabase.PostgREST.html#order/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.order/3","doc":"- Supabase ordering results: https://supabase.com/docs/reference/javascript/using-filters#order","ref":"Supabase.PostgREST.html#order/3-see-also"},{"type":"function","title":"Supabase.PostgREST.overlaps/3","doc":"Adds an 'overlaps' filter to the query, checking if the column's array overlaps with the specified values.","ref":"Supabase.PostgREST.html#overlaps/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.overlaps/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `values`: The array of values that must overlap with the column's value.","ref":"Supabase.PostgREST.html#overlaps/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.overlaps/3","doc":"iex> PostgREST.overlaps(filter_builder, \"tags\", [\"urgent\", \"old\"])","ref":"Supabase.PostgREST.html#overlaps/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.overlaps/3","doc":"- Supabase overlaps filter: https://supabase.com/docs/reference/javascript/using-filters#overlaps","ref":"Supabase.PostgREST.html#overlaps/3-see-also"},{"type":"function","title":"Supabase.PostgREST.range/4","doc":"Configures the query to limit results to a specific range based on offset and limit.","ref":"Supabase.PostgREST.html#range/4"},{"type":"function","title":"Parameters - Supabase.PostgREST.range/4","doc":"- `filter_builder`: The FilterBuilder instance.\n- `from`: The starting index for the results.\n- `to`: The ending index for the results, inclusive.","ref":"Supabase.PostgREST.html#range/4-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.range/4","doc":"iex> PostgREST.range(filter_builder, 0, 10)","ref":"Supabase.PostgREST.html#range/4-examples"},{"type":"function","title":"See also - Supabase.PostgREST.range/4","doc":"- Supabase range queries: https://supabase.com/docs/reference/javascript/using-filters#range","ref":"Supabase.PostgREST.html#range/4-see-also"},{"type":"function","title":"Supabase.PostgREST.range_adjacent/3","doc":"Filters the query by checking if the value of a column is adjacent to a specified range value.","ref":"Supabase.PostgREST.html#range_adjacent/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.range_adjacent/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The adjacent range value.","ref":"Supabase.PostgREST.html#range_adjacent/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.range_adjacent/3","doc":"iex> PostgREST.range_adjacent(filter_builder, \"scheduled_time\", \"2021-01-01T10:00:00Z/2021-01-01T12:00:00Z\")","ref":"Supabase.PostgREST.html#range_adjacent/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.range_adjacent/3","doc":"- Supabase adjacent range filters: https://supabase.com/docs/reference/javascript/using-filters#adjacent","ref":"Supabase.PostgREST.html#range_adjacent/3-see-also"},{"type":"function","title":"Supabase.PostgREST.range_gt/3","doc":"Filters the query by specifying that the value of a column must be greater than a certain point in a range.","ref":"Supabase.PostgREST.html#range_gt/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.range_gt/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The lower bound value of the range.","ref":"Supabase.PostgREST.html#range_gt/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.range_gt/3","doc":"iex> PostgREST.range_gt(filter_builder, \"age\", 20)","ref":"Supabase.PostgREST.html#range_gt/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.range_gt/3","doc":"- More on range filters at Supabase: https://supabase.com/docs/reference/javascript/using-filters#range","ref":"Supabase.PostgREST.html#range_gt/3-see-also"},{"type":"function","title":"Supabase.PostgREST.range_gte/3","doc":"Filters the query by specifying that the value of a column must be greater than or equal to a certain point in a range.","ref":"Supabase.PostgREST.html#range_gte/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.range_gte/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The starting value of the range.","ref":"Supabase.PostgREST.html#range_gte/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.range_gte/3","doc":"iex> PostgREST.range_gte(filter_builder, \"age\", 18)","ref":"Supabase.PostgREST.html#range_gte/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.range_gte/3","doc":"- Supabase documentation on range filters: https://supabase.com/docs/reference/javascript/using-filters#range","ref":"Supabase.PostgREST.html#range_gte/3-see-also"},{"type":"function","title":"Supabase.PostgREST.range_lt/3","doc":"Filters the query by specifying that the value of a column must be less than a certain point in a range.","ref":"Supabase.PostgREST.html#range_lt/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.range_lt/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The upper bound value of the range.","ref":"Supabase.PostgREST.html#range_lt/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.range_lt/3","doc":"iex> PostgREST.range_lt(filter_builder, \"age\", 30)","ref":"Supabase.PostgREST.html#range_lt/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.range_lt/3","doc":"- Supabase range filters: https://supabase.com/docs/reference/javascript/using-filters#range","ref":"Supabase.PostgREST.html#range_lt/3-see-also"},{"type":"function","title":"Supabase.PostgREST.range_lte/3","doc":"Filters the query by specifying that the value of a column must be less than or equal to a certain point in a range.","ref":"Supabase.PostgREST.html#range_lte/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.range_lte/3","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to apply the filter.\n- `value`: The ending value of the range.","ref":"Supabase.PostgREST.html#range_lte/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.range_lte/3","doc":"iex> PostgREST.range_lte(filter_builder, \"age\", 65)","ref":"Supabase.PostgREST.html#range_lte/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.range_lte/3","doc":"- Supabase guide on using range filters: https://supabase.com/docs/reference/javascript/using-filters#range","ref":"Supabase.PostgREST.html#range_lte/3-see-also"},{"type":"function","title":"Supabase.PostgREST.select/3","doc":"Selects records from a table. You can specify specific columns or use '*' for all columns.\nOptions such as counting results and specifying return types can be configured.","ref":"Supabase.PostgREST.html#select/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.select/3","doc":"- `query_builder`: The QueryBuilder instance.\n- `columns`: A list of column names to fetch or '*' for all columns.\n- `opts`: Options such as `:count` and `:returning`.","ref":"Supabase.PostgREST.html#select/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.select/3","doc":"iex> PostgREST.select(query_builder, \"*\", count: :exact, returning: true)","ref":"Supabase.PostgREST.html#select/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.select/3","doc":"- Supabase select queries: https://supabase.com/docs/reference/javascript/select","ref":"Supabase.PostgREST.html#select/3-see-also"},{"type":"function","title":"Supabase.PostgREST.single/1","doc":"Configures the query to expect and return only a single record as a result.\nThis modifies the header to indicate that only one object should be returned.","ref":"Supabase.PostgREST.html#single/1"},{"type":"function","title":"Parameters - Supabase.PostgREST.single/1","doc":"- `filter_builder`: The FilterBuilder instance to modify.","ref":"Supabase.PostgREST.html#single/1-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.single/1","doc":"iex> PostgREST.single(filter_builder)","ref":"Supabase.PostgREST.html#single/1-examples"},{"type":"function","title":"See also - Supabase.PostgREST.single/1","doc":"- Supabase single row mode: https://supabase.com/docs/reference/javascript/using-filters#single-row","ref":"Supabase.PostgREST.html#single/1-see-also"},{"type":"function","title":"Supabase.PostgREST.text_search/4","doc":"Performs a full-text search on a text column in the database, using different search configurations.","ref":"Supabase.PostgREST.html#text_search/4"},{"type":"function","title":"Parameters - Supabase.PostgREST.text_search/4","doc":"- `filter_builder`: The FilterBuilder instance.\n- `column`: The column to search.\n- `query`: The text query for the search.\n- `opts`: Options for the search, such as type of search (`:plain`, `:phrase`, or `:websearch`) and configuration.","ref":"Supabase.PostgREST.html#text_search/4-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.text_search/4","doc":"iex> PostgREST.text_search(filter_builder, \"description\", \"elixir supabase\", type: :plain)","ref":"Supabase.PostgREST.html#text_search/4-examples"},{"type":"function","title":"See also - Supabase.PostgREST.text_search/4","doc":"- Supabase full-text search capabilities: https://supabase.com/docs/reference/javascript/using-filters#full-text-search","ref":"Supabase.PostgREST.html#text_search/4-see-also"},{"type":"function","title":"Supabase.PostgREST.update/3","doc":"Updates existing records in the database. Allows specifying return options and how the update is counted.","ref":"Supabase.PostgREST.html#update/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.update/3","doc":"- `query_builder`: The QueryBuilder to use.\n- `data`: The new data for the update, typically a map or list of maps.\n- `opts`: Options such as `:returning` and `:count`.","ref":"Supabase.PostgREST.html#update/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.update/3","doc":"iex> PostgREST.update(query_builder, %{name: \"Doe\"}, returning: :representation)","ref":"Supabase.PostgREST.html#update/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.update/3","doc":"- Supabase documentation on updates: https://supabase.com/docs/reference/javascript/update","ref":"Supabase.PostgREST.html#update/3-see-also"},{"type":"function","title":"Supabase.PostgREST.upsert/3","doc":"Upserts data into a table, allowing for conflict resolution and specifying return options.","ref":"Supabase.PostgREST.html#upsert/3"},{"type":"function","title":"Parameters - Supabase.PostgREST.upsert/3","doc":"- `query_builder`: The QueryBuilder to use.\n- `data`: The data to upsert, typically a map or a list of maps.\n- `opts`: Options like `:on_conflict`, `:returning`, and `:count`.","ref":"Supabase.PostgREST.html#upsert/3-parameters"},{"type":"function","title":"Examples - Supabase.PostgREST.upsert/3","doc":"iex> PostgREST.upsert(query_builder, %{name: \"Jane\"}, on_conflict: \"name\", returning: :representation)","ref":"Supabase.PostgREST.html#upsert/3-examples"},{"type":"function","title":"See also - Supabase.PostgREST.upsert/3","doc":"- Supabase documentation on upserts: https://supabase.com/docs/reference/javascript/upsert","ref":"Supabase.PostgREST.html#upsert/3-see-also"},{"type":"module","title":"Supabase.PostgREST.Error","doc":"","ref":"Supabase.PostgREST.Error.html"},{"type":"function","title":"Supabase.PostgREST.Error.from_raw_body/1","doc":"","ref":"Supabase.PostgREST.Error.html#from_raw_body/1"},{"type":"type","title":"Supabase.PostgREST.Error.t/0","doc":"","ref":"Supabase.PostgREST.Error.html#t:t/0"},{"type":"module","title":"Supabase.PostgREST.FilterBuilder","doc":"","ref":"Supabase.PostgREST.FilterBuilder.html"},{"type":"function","title":"Supabase.PostgREST.FilterBuilder.add_header/3","doc":"","ref":"Supabase.PostgREST.FilterBuilder.html#add_header/3"},{"type":"function","title":"Supabase.PostgREST.FilterBuilder.add_param/3","doc":"","ref":"Supabase.PostgREST.FilterBuilder.html#add_param/3"},{"type":"function","title":"Supabase.PostgREST.FilterBuilder.from_query_builder/1","doc":"","ref":"Supabase.PostgREST.FilterBuilder.html#from_query_builder/1"},{"type":"function","title":"Supabase.PostgREST.FilterBuilder.new/0","doc":"","ref":"Supabase.PostgREST.FilterBuilder.html#new/0"},{"type":"type","title":"Supabase.PostgREST.FilterBuilder.t/0","doc":"","ref":"Supabase.PostgREST.FilterBuilder.html#t:t/0"},{"type":"extras","title":"Supabase PostgREST","doc":"# Supabase PostgREST\n\n[PostgREST](https://postgrest.org/en/v12/) implementation for the `supabase_potion` SDK in Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - Supabase PostgREST","doc":"```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.3\"},\n    {:supabase_postgrest, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Supabase PostgREST","doc":"Firstly you need to initialize your Supabase client(s) as can be found on the [supabase_potion documentation](https://hexdocs.pm/supabase_potion/Supabase.html#module-starting-a-client):\n\n```elixir\niex> Supabase.init_client(%{name: Conn, conn: %{base_url: \" \", api_key: \" \"}})\n{:ok, #PID<>}\n```\n\nNow you can pass the Client to the `Supabase.PostgREST` functions as a `PID` or the name that was registered on the client initialization:\n\n```elixir\niex> Supabase.Storage.list_buckets(pid | client_name)  \n```","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}